function HANDLE = gui_create_logo(HANDLE, logo_string, logo_parent, ...
    meta_frame, logo_type);
%
% Creates logo for TUG and ITP
%
% Author:  Winfried Kernbichler
% Version: 1.1 
% Date:    October 20, 2001
% Status:  Works well, only one logo type defined

switch logo_type  
  % ========================================================================
  % logo number 1
  case 'logo_1'
    % ----------------------------------------------------------------------
    % definition
    % ----------------------------------------------------------------------
    l_ax_color = [0.9,0.9,0.9];
    x_min_pos = meta_frame(1);
    x_div_pos = 0.15 * meta_frame(3);
    x_max_pos = meta_frame(1) + meta_frame(3);
    y_min_pos = meta_frame(2);
    y_siz_pos = meta_frame(4);
    % ----------------------------------------------------------------------
        
    % ----------------------------------------------------------------------
    % header left
    % ----------------------------------------------------------------------
    x_siz_pos = x_div_pos;
    geom = [x_min_pos, y_min_pos, x_siz_pos, y_siz_pos]; 
    F.axes = struct( ...
	'frame',    { geom }, ...
	'xborder',  { [0.0, 0.0] }, ...
	'yborder',  { [0.0, 0.0] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...
	'geometry', { [1] }, ...
	'parent',   { [logo_parent] }, ...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'xtick',    { [] }, ...
	'ytick',    { [] }, ...
	'color',    { l_ax_color }, ...
	'xcolor',   { l_ax_color }, ...
	'ycolor',   { l_ax_color }, ...	
	'tag',      { 'logo_header_left' } ...
	);
    [HANDLE,nh] = gui_create(gui_define(F),HANDLE);
    clear F;
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------
    % image left
    % ----------------------------------------------------------------------
    F.axes = struct( ...
	'frame',    { geom }, ...
	'xborder',  { [0.02, 0.00] }, ...
	'yborder',  { [0.1, 0.1] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...
	'geometry', { [1] }, ...
	'parent',   { [logo_parent] }, ...
	'visible',  { 'off' }, ...
	'tag',      { 'logo_image_left' } ...
	);
    [HANDLE,nh] = gui_create(gui_define(F),HANDLE);
    clear F;
    
    tug = imread('logo-tug.png');
    stug = sum(tug,3);
    atug = ones(size(stug));
    atug(stug==765)=0;
    imh = image(tug); axis equal;
    set(imh,'alphadata',atug,'tag','logo_image_left')
    set(gca,'Visible','off')
    [HANDLE,nhi] = gui_create(imh,HANDLE);
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------
    % header middle
    % ----------------------------------------------------------------------
    x_siz_pos = x_max_pos - 2*x_div_pos;
    geom = [x_div_pos, y_min_pos, x_siz_pos, y_siz_pos]; 
    F.axes = struct( ...
	'frame',    { geom }, ...
	'xborder',  { [0.0, 0.0] }, ...
	'yborder',  { [0.0, 0.0] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...
	'geometry', { [1] }, ...
	'parent',   { [logo_parent] }, ...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'xtick',    { [] }, ...
	'ytick',    { [] }, ...
	'color',    { l_ax_color }, ...
	'xcolor',   { l_ax_color }, ...
	'ycolor',   { l_ax_color }, ...	
	'tag',      { 'logo_header_middle' } ...
	);
    [HANDLE,nh] = gui_create(gui_define(F),HANDLE);
    clear F;
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------
    % text middle
    % ----------------------------------------------------------------------
    GUI.text = struct( ...
	'position',   { [0.5,0.5] }, ...
	'fontunits',  { 'normalized' }, ...
	'fontsize',   { 0.20 }, ...
	'fontweight', { 'bold' }, ...
	'horizontalalignment', { 'center' }, ...
	'color',      { 'black' }, ...
	'string',     { logo_string }, ...
	'tag',        { 'logo_header_text' } ...
	);
    [HANDLE,nht] = gui_create(GUI,HANDLE);
    clear GUI;
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------
    % header right
    % ----------------------------------------------------------------------
    x_siz_pos = x_div_pos;
    geom = [x_max_pos-x_div_pos, y_min_pos, x_siz_pos, y_siz_pos]; 
    F.axes = struct( ...
	'frame',    { geom }, ...
	'xborder',  { [0.0, 0.0] }, ...
	'yborder',  { [0.0, 0.0] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...
	'geometry', { [1] }, ...
	'parent',   { [logo_parent] }, ...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'xtick',    { [] }, ...
	'ytick',    { [] }, ...
	'color',    { l_ax_color }, ...
	'xcolor',   { l_ax_color }, ...
	'ycolor',   { l_ax_color }, ...	
	'tag',      { 'logo_header_right' } ...
	);
    [HANDLE,nh] = gui_create(gui_define(F),HANDLE);
    clear F;
    % ----------------------------------------------------------------------
        
    % ----------------------------------------------------------------------
    % image right
    % ----------------------------------------------------------------------
    F.axes = struct( ...
	'frame',    { geom }, ...
	'xborder',  { [0.00, -0.02] }, ...
	'yborder',  { [0.1, 0.1] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...
	'geometry', { [1] }, ...
	'parent',   { [logo_parent] }, ...
	'visible',  { 'off' }, ...
	'tag',      { 'logo_image_right' } ...
	);
    [HANDLE,nh] = gui_create(gui_define(F),HANDLE);
    clear F;
    
    itp = imread('logo-itp.png');
    sitp = sum(itp,3);
    aitp = ones(size(sitp));
    aitp(sitp>700)=0;
    imh = image(itp); axis equal;
    set(imh,'alphadata',aitp,'tag','logo_image_right')
    set(gca,'Visible','off')
    [HANDLE,nhi] = gui_create(imh,HANDLE);
    % ----------------------------------------------------------------------
    
  % ========================================================================
  % logo not defined
  otherwise
    error('This logo is not defined!')
end

