function GUI = gui_define(DEFINE)
%
% Defines structure GUI as defined in gui_create from a structure DEFINE.
%
%    F.figure = struct( ...
%	'frame',    { [0,0.3,1,0.7] }, ...
%	'geometry', { [2,2,3,3;2,2,3,3;1,1,3,3;1,1,3,3] }, ...
%	'color',    { 'red' }, ...
%	'visible',  { 'off' }, ...
%	);
%    [HANDLE,new_handle] = gui_create(gui_define(F));
%
%    F3.axes = struct( ...
%	'frame',    { [0,0.3,1,0.7] }, ...
%	'geometry', { [1,1;3,3] }, ...
%	'parent',   { [3] }, ...
%	'color',    {'blue'} ...
%	);
%    F3.uicontrol = struct( ...
%	'frame',    { [0.2,0,0.6,0.3] }, ...
%	'geometry', { [1;1;1;1;1] }, ...
%	'parent',   { [3] }, ...
%	'style',    { 'slider' } ...
%	);
%    [HANDLE,new_handle] = gui_create(gui_define(F3),HANDLE);
%
% Properties can be all valid matlab properties and properties related to
% geometry given in gui_default.
% 
% Author:  Winfried Kernbichler
% Version: 1.0 
% Date:    October 17, 2001
% Status:  Workes very well in all tests at the moment
% Missing: Check of input


objects = fieldnames(DEFINE);   % all objects in DEFINE 
for obj_l = 1:length(objects)   % cycle through objects
  obj = char(objects(obj_l));   % one object
  % get geometry defaults
  e_str = ['GEOM.',obj,'=gui_default(''geometry'',''',obj,''');'];
  eval(e_str);
  
  % Merging of DEFINE and GEOM
  define_prop  = fieldnames( eval( ['DEFINE.',obj] ) );  % all DEFINE properties
  default_prop = fieldnames( eval( ['GEOM.',obj] ) );    % all geometry properties
  default_num  = length( default_prop );                 % and their number
  for prop_l = 1:default_num                             % merging with DEFINE
    prop = char(default_prop(prop_l));                   % DEFINE overrules GEOM
    if ~any(strcmp(prop,define_prop))
      e_str = ['DEFINE.',obj,'=setfield(DEFINE.',obj,',{1},''',prop,''','];
      e_str = [e_str,'GEOM.',obj,'.',prop,');'];
      eval(e_str);
      %eval( ['DEFINE.',obj,'.',prop,'=','GEOM.',obj,'.',prop,';'] );
    end
  end  
  
  % extract geometry related quantities and construct GUI_I (intermediate stuff)
  define_prop = fieldnames( eval( ['DEFINE.',obj] ) );  % all define properties
  define_num  = length( define_prop );                  % and their number
  for prop_l = 1:define_num
    prop = char(define_prop(prop_l));
    val  = ['{DEFINE.',obj,'.',prop,'}'];
    if any(strcmp(prop,default_prop))
      eval( [prop,'=','DEFINE.',obj,'.',prop,';'] );    % geometry variable
    else
      eval( ['GUI_I.',obj,'.',prop,'=',val,';'] );      % real object quantity
    end
  end
    % Handle all questions of geometry
  geometry = flipud(geometry);     % to be able to start from lower left corner
  [ynum,xnum] = size(geometry);    % number of standard objects
  xtsize  = sizetot(3);            % total size in x
  ytsize  = sizetot(4);            % total size in y
  
  switch sizeunits
    case 'pixels'
      xfstart = fix(frame(1).*xtsize); % x-frame starting point
      yfstart = fix(frame(2).*ytsize); % y-frame starting point
      xfsize  = fix(frame(3).*xtsize); % x-frame size
      yfsize  = fix(frame(4).*ytsize); % y-frame size
      x_size   = ...                    % x-size of standard object
	  fix((xfsize - sum(xborder) - (xnum-1).*xgap)/xnum);
      y_size   = ...                    % y-size of standard object
	  fix((yfsize - sum(yborder) - (ynum-1).*ygap)/ynum);
    case 'normalized'
      xfstart = frame(1).*xtsize; % x-frame starting point
      yfstart = frame(2).*ytsize; % y-frame starting point
      xfsize  = frame(3).*xtsize; % x-frame size
      yfsize  = frame(4).*ytsize; % y-frame size
      xborder = xborder * xfsize / xtsize; % renormalization 
      yborder = yborder * yfsize / ytsize;
      xgap    = xgap * xfsize / xtsize;
      ygap    = ygap * yfsize / ytsize;
      xedge   = xedge * xfsize / xtsize;
      yedge   = yedge * yfsize / ytsize;
      xsize   = xsize * xfsize / xtsize;
      ysize   = ysize * yfsize / ytsize;
      xshift  = xshift * xfsize / xtsize;
      yshift  = yshift * yfsize / ytsize;
      x_size   = ...                    % x-size of standard object
	  (xfsize - sum(xborder) - (xnum-1).*xgap)/xnum;
      y_size   = ...                    % y-size of standard object
	  (yfsize - sum(yborder) - (ynum-1).*ygap)/ynum;
  end
  exclude = [0];                   % excluded numbers
  count   = 0;                     % counter of objects
  pos     = [];                    % start with an empty position vector
  obj_mat = [];                    % and empty object matrix
  for my = 1:ynum                  % cycle through location on frame (y)
      for mx = 1:xnum                % cycle through location on frame (x)
          g = geometry(my,mx);         % take value from geometry matrix
          if ~any(g==exclude)          % valid place
              count = count + 1;         % counter
              obj_mat(count,:)=[mx,my];  % remember which objects are present
              if g==1                    % standar object
                  lx = 1;
                  ly = 1;
              else                       % overlapping stuff
                  xvec = geometry(my,mx:xnum);         % submatrix x
                  yvec = geometry(my:ynum,mx);         % submatrix y
                  lx   = length(xvec(xvec==g));        % size of submatrix x
                  ly   = length(yvec(yvec==g));        % size of submatrix y
                  geometry(my:my+ly-1,mx:mx+lx-1) = 0; % reset portion of geometry
              end
              xpstart = xfstart+xborder(1)+(mx-1).*(x_size+xgap)+xshift;
              ypstart = yfstart+yborder(1)+(my-1).*(y_size+ygap)+yshift;
              xpsize  = x_size*lx + (xgap + sum(xedge))*(lx-1);
              ypsize  = y_size*ly + (ygap + sum(yedge))*(ly-1);
              switch xmodify
              case 'left'
                  xpsize  = xsize;
              case 'center'
                  xpstart = xpstart + (xpsize - xsize)/2;
                  if strcmp(sizeunits,'pixels'), xpstart = fix(xpstart); end
                  xpsize  = xsize;                  
              case 'right'
                  xpstart = xpstart + xpsize - xsize;	    
                  xpsize  = xsize;
              end
              switch ymodify
              case 'bottom'
                  ypsize  = ysize;
              case 'middle'
                  ypstart = ypstart + (ypsize - ysize)/2;
                  if strcmp(sizeunits,'pixels'), ypstart = fix(ypstart); end
                  ypsize  = ysize;
              case 'top'
                  ypstart = ypstart + ypsize - ysize;	    
                  ypsize  = ysize;
              end
	    
              % position matrix
              pos(count,:) = [xpstart,ypstart,xpsize, ypsize];
          end
      end
  end
  
  % Finish GUI for a given object
  if ~exist('GUI_I')
      eval( ['GUI_I.',obj,'= struct([]);'] );
  elseif ~isfield(GUI_I,obj)
      eval( ['GUI_I.',obj,'= struct([]);'] );
  end
  eval( ['GUI.',obj,'= struct([]);'] );               % create GUI.obj    
  exist_prop = fieldnames( eval( ['GUI_I.',obj] ) );  % all real properties
  exist_pnum = length( exist_prop );                  % and their number
  exist_vnum = size(pos,1);                           % number of values 
  % set position property
  for k = 1:exist_vnum;                               % cycle through all positions 
    eval( ['GUI.',obj,'=setfield(','GUI.',obj,',{k},''position'',pos(k,:));'] );
  end
  % set all other properties
  for l = 1:exist_pnum                                % cycle through properties
    prop = char(exist_prop(l));                       % extract a property
    % distiguish between one or more values
    if eval( ['iscell(GUI_I.',obj,'.',prop,'{1})'] )  % values in a cell
      eval( ['val=GUI_I.',obj,'.',prop,';'] );
      val{1} = flipud(val{1});
      for k = 1:size(obj_mat,1)
          mx = obj_mat(k,1);
          my = obj_mat(k,2);
          act_val = val{1}(my,mx);
          e_str = ['GUI.',obj,'=setfield(','GUI.',obj,',{k},''',prop,''',act_val{1});'];
          eval(e_str);	
      end
    else                                              % one value
      eval( ['act_val=GUI_I.',obj,'.',prop,';'] );
      for k = 1:size(obj_mat,1)
          e_str = ['GUI.',obj,'=setfield(','GUI.',obj,',{k},''',prop,''',act_val{1});'];
          eval(e_str);	
      end
    end
  end  
  % remove geometry quantities
  for prop_l = 1:default_num
    prop = char(define_prop(prop_l));
    eval( ['clear ',prop,';'] );
  end  
end





