%Berechnung der neuen Spinmatrix
function [spin_matrix,k]=ising_it(spin_matrix,iterations,temperature,time_delay,resume_faktor,cluster_faktor,varargin)
%
% Iteration fuer das 2D Ising Modell
%
% Autor:  Winfried Kernbichler, Dieter Mayer
% Version: 1.0 
% Datum:    11. November 2001
% Status:  Works for simple and complicated update scenario

%Fragt, wieviele Input-Parameter existieren
if nargin<1, error('Ising_it: Not enough input parameters!'); end
if nargin<2, iterations = 100;  end
if nargin<3, temperature = 1.5;  end
if nargin<4, time_delay = 0.0;  end
if nargin<5, resume_faktor = 0;  end
if nargin<6, cluster_faktor = 0;  end

if temperature == 0
    temperature=eps;
end 

% check for graphics handle
graph_swi = 0;
if nargin >= 7    
    graph_h = varargin{1};
    if all(ishandle(graph_h))
        graph_swi = 1;
        image_h      = graph_h(1);
        if length(graph_h)>1
            %simple = 'n';
            mag_it_h            = graph_h(2);
            energ_it_h          = graph_h(3);
            mag_temp_h          = graph_h(4);
            mag_temp_exakt_h    = graph_h(5);
            energ_temp_h        = graph_h(6);
            energ_temp_exakt_h  = graph_h(7);
        else
            %simple = 'y';
        end
    end
end
    
% check for stop handle
stop_swi  = 0;
if nargin >= 8
    stop_h = varargin{2};
    if all(ishandle(stop_h))    
        stop_swi = 1;
    end
end


%periodische Matrix sowie Koordinaten der Untergitter werden abgefragt bzw. erzeugt
[spin_up_down_period,pos]=matrix_periodisch(spin_matrix);
[y_dimension,x_dimension]=size(spin_matrix);

%in den vorherigen Iterationen erzeugte Daten
magnetisierung_temp_bisher=get(mag_temp_h,'ydata');
energie_temp_bisher=get(energ_temp_h,'ydata');
temp_bisher=get(energ_temp_h,'xdata');


    
if length(magnetisierung_temp_bisher)>1
    magnetisierung_temp_bisher=magnetisierung_temp_bisher(1:end-1);
    energie_temp_bisher=energie_temp_bisher(1:end-1);
    temp_bisher=temp_bisher(1:end-1);
else
    magnetisierung_temp_bisher=[];
    energie_temp_bisher=[];
    temp_bisher=[];
end

switch resume_faktor
    %unterscheidet, ob bei alten Iterationen fortgesetzt werden soll, oder ob neue erzeugt werden
case 0    
    iterations_faktor=0;
case 1
    iterations_faktor=length(get(mag_it_h,'xdata'));    
    magnetisierung=get(mag_it_h,'ydata');
    energie_aktuell=get(energ_it_h,'ydata');
end

%Vorbereitungen fuer die Cluster-Verarbeitung
if cluster_faktor==1
    %berechnet die Koordinaten der benachbarten Spins
    horizontal=[linspace(y_dimension,y_dimension,y_dimension*(x_dimension-1)) ...
            linspace(-y_dimension*(x_dimension-1),-y_dimension*(x_dimension-1),y_dimension)];
    vertikal=repmat([ones(1,y_dimension-1) -(y_dimension-1)],[1,x_dimension]);
    stellen=reshape(repmat(1:x_dimension*y_dimension,[2,1]),[2*x_dimension*y_dimension,1]);
    neighbours= [stellen reshape([vertikal',horizontal']',[2*x_dimension*y_dimension,1])+stellen];

    unten=vertikal;
    rechts=horizontal;
    links=-fliplr(rechts);
    oben=-fliplr(unten);

    nextn=[unten'+(1:x_dimension*y_dimension)' rechts'+(1:x_dimension*y_dimension)'...
            links'+(1:x_dimension*y_dimension)' oben'+(1:x_dimension*y_dimension)']; 
end

%Berechnung der Energie pro Spin
for untergitter=1:2
    energie_gesamt(untergitter)=sum(sum(energie(spin_up_down_period,pos(untergitter,:))));      
end
energie_gesamt=sum(energie_gesamt);
    
for k=(1+iterations_faktor):(iterations+iterations_faktor)
    %Beruecksichtigung einer eventuellen Zeitverzoegerung
    t0 = clock; et=0; while et<time_delay; et = etime(clock,t0); end   
    
    switch cluster_faktor
    case 0        
        zufallsmatrix=rand(2,(y_dimension*x_dimension)/2);                %Erstellung einer L*L Zufallsmatrix (0,1) fuer das Metropolis Verfahren        
        for untergitter=1:2
            energie_einzel=energie(spin_up_down_period,pos(untergitter,:));        
            %Matrix mit Spins, die geflippt werden 
            spinflip=zufallsmatrix(untergitter,:)<exp(2*energie_einzel/temperature);                
            spin_up_down_period(pos(untergitter,find(spinflip)))=-1*spin_up_down_period(pos(untergitter,find(spinflip)));
            %periodische Fortsetzung des Gitters an den Raendern    
            spin_up_down_period(1,2:x_dimension+1)=spin_up_down_period(y_dimension+1,2:x_dimension+1);                      
            spin_up_down_period(y_dimension+2,2:x_dimension+1)=spin_up_down_period(2,2:x_dimension+1);
            spin_up_down_period(2:y_dimension+1,1)=spin_up_down_period(2:y_dimension+1,x_dimension+1);
            spin_up_down_period(2:y_dimension+1,x_dimension+2)=spin_up_down_period(2:y_dimension+1,2);           
            energie_gesamt=energie_gesamt-4*sum(energie_einzel(spinflip));
        end    
        %Ausschneiden der urspruenglichen Spinmatrix aus der vergroesserten periodischen Matrix
        spin_matrix=spin_up_down_period(2:y_dimension+1,2:x_dimension+1);
        %Berechnung der Energie und der Magnetisierung
        energie_aktuell(k)=energie_gesamt/(x_dimension*y_dimension);        
        magnetisierung(k)=sum(sum(spin_up_down_period(2:y_dimension+1,2:x_dimension+1)))/(x_dimension*y_dimension);
    case 1
        %Cluster-Algorithmus
        spins=reshape(spin_matrix,[],1);
        bound=[neighbours (spins(neighbours(:,1))==spins(neighbours(:,2))) & (rand(2*x_dimension*y_dimension,1)<(1-exp(-2/temperature)))];
        bound(find(bound==0))=nan;
        minimum=1:x_dimension*y_dimension;
        position=1:x_dimension*y_dimension;
        differenz=1;
        minimum_alt=position;

        h5=bound((position-1)*2+1,3);
        h6=bound((position-1)*2+2,3);
        h7=bound((nextn(position,3)-1)*2+2,3);
        h8=bound((nextn(position,4)-1)*2+1,3);
        bound_ja_nein=[h5 h6 h7 h8];
        zufallsmatrix=2*round(rand(1,x_dimension*y_dimension))-1;
        while differenz>0
            minimum=min(([minimum_alt(nextn).*bound_ja_nein position'])');
            minimum=minimum(minimum);
            differenz=(max(max(abs(minimum-minimum_alt))));
            minimum_alt=minimum;
        end
        zufallsmatrix=zufallsmatrix(minimum);
        spins=spins.*zufallsmatrix';
        %Spinmatrix
        spin_matrix=reshape(spins,[y_dimension,x_dimension]);   
        %Berechnung der Magnetisierung und Energie
        magnetisierung(k)=sum(sum(spin_matrix))/(x_dimension*y_dimension);
        [spin_up_down_period,pos]=matrix_periodisch(spin_matrix);
        energie_aktuell(k)=(sum(sum(energie(spin_up_down_period,pos(1,:))+energie(spin_up_down_period,pos(2,:)))))/(x_dimension*y_dimension);
    end
    
    if mod(k,1)==0
        %nur jede 5. Iteration wird dargestellt
        if graph_swi, 
            % update image            
            set(image_h,'cdata', spin_matrix);
            
            set(mag_it_h,'xdata',1:k,'ydata',(magnetisierung));
            set(energ_it_h,'xdata',1:k,'ydata',(energie_aktuell));
            
            set(mag_temp_h,'xdata',[temp_bisher,temperature],'ydata',[magnetisierung_temp_bisher,mean(abs(magnetisierung(round(k/2):k)))]);
            set(energ_temp_h,'xdata',[temp_bisher,temperature],'ydata',[energie_temp_bisher,mean(energie_aktuell(round(k/2):k))]);
            drawnow
        end  
        %set(handle_zeit,'string',strcat('t =',num2str(iterations_zahl)));        
    end    
    % Berechnung der Standardabweichung der absoluten Magnetisierung aus der letzten Haelfte der Magnetisierung    
    standard_abweichung=std((abs(magnetisierung(round((k)/2):k))))/sqrt(k);
    if (standard_abweichung<0.001 & k>50), break; end          % Konvergenz, Abbruch der Iterationen

    if stop_swi                                                % check stop button
        stop_val = gui_get_userdata(stop_h,'stop');
        if stop_val
            break
        end
    end
end

